==> haskell-generically-0.1.1-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generically.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generically
version:              0.1.1
visibility:           public
id:                   generically-0.1.1-KmLNJTyhTyTJzHiTd4hvSZ
key:                  generically-0.1.1-KmLNJTyhTyTJzHiTd4hvSZ
license:              BSD-3-Clause
copyright:            2022 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus
synopsis:             Generically newtype to use with DerivingVia
description:
    This is a compatibility package as @Generically@ and @Generically1@ newtypes
    are available since @base-4.17@ in '\''GHC.Generics'\''.

category:             Generics
abi:                  427f1564e8b226ad02d7a0a190b376d3
exposed:              True
exposed-modules:      GHC.Generics.Generically
import-dirs:          /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generically
hs-libraries:         HSgenerically-0.1.1-KmLNJTyhTyTJzHiTd4hvSZ
depends:
    base-4.17.2.1 base-orphans-0.9.3-B3znDJ5a8mWCr1SR1mJ1h1

haddock-interfaces:   /usr/share/doc/haskell-generically/html/generically.haddock
haddock-html:         /usr/share/doc/haskell-generically/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generically-0.1.1-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generically.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generically
version:              0.1.1
visibility:           public
id:                   generically-0.1.1-L2P9BZzvyDDKzrrFQ0qlvb
key:                  generically-0.1.1-L2P9BZzvyDDKzrrFQ0qlvb
license:              BSD-3-Clause
copyright:            2022 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus
synopsis:             Generically newtype to use with DerivingVia
description:
    This is a compatibility package as @Generically@ and @Generically1@ newtypes
    are available since @base-4.17@ in '\''GHC.Generics'\''.

category:             Generics
abi:                  f0b951b828daa95456b5f3128fa0e6bc
exposed:              True
exposed-modules:      GHC.Generics.Generically
import-dirs:          /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generically
hs-libraries:         HSgenerically-0.1.1-L2P9BZzvyDDKzrrFQ0qlvb
depends:
    base-4.17.2.1 base-orphans-0.9.3-KjEwzlW93pECocqzLBwG3l

haddock-interfaces:   /usr/share/doc/haskell-generically/html/generically.haddock
haddock-html:         /usr/share/doc/haskell-generically/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
